
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef MTI_MSG_LIB_H
#define MTI_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "MTIType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  MTI_MBOX_NAME                  genomInstanceName("MTI")

#define  MTI_MAX_RQST_SIZE              128

#define  MTI_MBOX_RQST_SIZE       \
 (BUF_SIZE(MTI_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  MTI_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  MTI_MAX_REPLY_SIZE             28

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  MTI_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(MTI_MAX_REPLY_SIZE) \
   + BUF_SIZE(MTI_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define MTI_INIT_RQST 0
#define MTI_CONFIG_RQST 1
#define MTI_RESET_RQST 2
#define MTI_LOG_RQST 3
#define MTI_STOPLOG_RQST 4
#define MTI_GETCONFIGURATION_RQST 5
#define MTI_AVERAGESAMPLES_RQST 6
#define MTI_SETBIASES_RQST 7
#define MTI_GETBIASES_RQST 8
#define MTI_ABORT_RQST 9


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS MTIClientInit (CLIENT_ID *pClientId);

STATUS MTIClientEnd (CLIENT_ID clientId);

int MTIAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int MTIAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int MTIAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS MTIInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 INERTIAL_DEVICE *(in_device),
					 int replyTimeOut);

extern int MTIInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTIInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					INERTIAL_DEVICE *(in_device), 
					
					int *activity, int *bilan);

extern int MTIInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					INERTIAL_DEVICE *(in_device), 
					
					int *activity,
					int *bilan);




extern STATUS MTIConfigRqstSend (CLIENT_ID clientId, int *pRqstId,
					 INERTIAL_CONFIG *(in_config),
					 int replyTimeOut);

extern int MTIConfigReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTIConfigRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					INERTIAL_CONFIG *(in_config), 
					
					int *activity, int *bilan);

extern int MTIConfigRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					INERTIAL_CONFIG *(in_config), 
					
					int *activity,
					int *bilan);




extern STATUS MTIResetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int MTIResetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTIResetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int MTIResetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS MTILogRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_fileName),
					 int replyTimeOut);

extern int MTILogReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTILogRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity, int *bilan);

extern int MTILogRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS MTIStopLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MTIStopLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int MTIStopLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS MTIGetConfigurationRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MTIGetConfigurationReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       INERTIAL_CONFIG *(out_config),
			       int *bilan);

int MTIGetConfigurationRqstAndRcv (CLIENT_ID clientId, 
				  
				 INERTIAL_CONFIG *(out_config),
				 int *bilan);




extern STATUS MTIAverageSamplesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 AVERAGING_PARAMETERS *(in_averagingParameters),
					 int replyTimeOut);

extern int MTIAverageSamplesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTIAverageSamplesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					AVERAGING_PARAMETERS *(in_averagingParameters), 
					
					int *activity, int *bilan);

extern int MTIAverageSamplesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					AVERAGING_PARAMETERS *(in_averagingParameters), 
					
					int *activity,
					int *bilan);




extern STATUS MTISetBiasesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 MTI_BIASES *(in_biases),
					 int replyTimeOut);

extern int MTISetBiasesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MTISetBiasesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					MTI_BIASES *(in_biases), 
					
					int *activity, int *bilan);

extern int MTISetBiasesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					MTI_BIASES *(in_biases), 
					
					int *activity,
					int *bilan);




extern STATUS MTIGetBiasesRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MTIGetBiasesReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       MTI_BIASES *(out_biases),
			       int *bilan);

int MTIGetBiasesRqstAndRcv (CLIENT_ID clientId, 
				  
				 MTI_BIASES *(out_biases),
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* MTI_MSG_LIB_H */

